==> fillets-ng-data_0.7.1.orig.tar.gz: fillets-ng-data-0.7.1/script/elevator2/dialogs_cs.lua <==

dialogId("zd2-m-dalsi", "font_small", "Another elevator? How many more are there to come?")
dialogStr("Další výtah? Kolik jich ještě bude?")


dialogId("zd2-v-odlis0", "font_big", "I can see some differences here... And somehow I don`t think it`s going to be easier.")
dialogStr("Vidím tu jisté drobné odlišnosti... A něco mi říká, že to teď není jednodušší.")


dialogId("zd2-v-odlis1", "font_big", "The last one had a little bit more advantageous architecture, I think.")
dialogStr("Ten minulý měl, myslím, trochu příznivější architekturu.")


dialogId("zd2-v-vlevo", "font_big", "Can you see that thing in the lower left? It must be some ancient religious symbol.")
dialogStr("Vidíš tu věc vlevo dole? To je jistě nějaký prastarý náboženský symbol.")


dialogId("zd2-m-nevid0", "font_small", "Fortunately, I can`t see much of it.")
dialogStr("Naštěstí na něj moc nevidím.")


dialogId("zd2-m-nevid1", "font_small", "If you are right, I`d rather not know what kind of religion it was.")
dialogStr("Jestli máš pravdu, tak radši nechci vědět koho.")


dialogId("zd2-v-symbol", "font_big", "I am afraid that if we use that strange symbol we could unwillingly initiate some dark ritual.")
dialogStr("Bojím se, že při použítí toho podivného symbolu bezděky spustíme nějaký temný rituál.")


dialogId("zd2-m-douf", "font_small", "I just hope it won`t drop on my head.")
dialogStr("Já jen doufám, že mi při tom nespadne na hlavu.")


dialogId("zd2-m-lebka", "font_small", "Another skull. It`s worse than a morgue.")
dialogStr("Zase nějaká lebka. Je to tu horší než v márnici.")


dialogId("zd2-v-haml", "font_big", "It`s worse than Hamlet.")
dialogStr("Je to tu horší než v Hamletovi.")


dialogId("zd2-x-hus0", "font_lightgrey", "Hush, hush!")
dialogStr("Huš, huš!")


dialogId("zd2-x-hus1", "font_lightgrey", "Don`t come near!")
dialogStr("Nepřibližuj se!")


dialogId("zd2-x-kricet", "font_lightgrey", "I`ll scream if you touch me.")
dialogStr("Jestli na mě sáhneš, budu křičet.")


dialogId("zd2-x-krik0", "font_lightgrey", "Aaaaa!")
dialogStr("ááááaa")


dialogId("zd2-x-krik1", "font_lightgrey", "Help!")
dialogStr("Pomóc.")


dialogId("zd2-x-ritual", "font_lightgrey", "I`ll initiate a dark ritual!")
dialogStr("Spustím temný rituál.")


dialogId("zd2-x-nechteme", "font_lightgrey", "Leave me alone!")
dialogStr("Nechte mě na pokoji!")


dialogId("zd2-x-nechme", "font_lightgrey", "Leave me alone and get lost!")
dialogStr("Necháš mě, dej pokoj!")


dialogId("zd2-x-pokoj", "font_lightgrey", "Cut it out!")
dialogStr("Dej pokoj!")


dialogId("zd2-x-fuj", "font_lightgrey", "Yuck, don`t nibble me!")
dialogStr("Fuj, neočuchávej mě!")


dialogId("zd2-x-necurat", "font_lightgrey", "Don`t think you can pee on me.")
dialogStr("Ne že se ke mě vyčůráš.")


dialogId("zd2-x-neklast", "font_lightgrey", "Just forget about laying your spawn here.")
dialogStr("Jestli tady chceš klást jikry, tak na to zapomeň.")

==> fillets-ng-data-1.0.0.tar.gz: fillets-ng-data-1.0.0/script/elevator2/dialogs_cs.lua <==

dialogId("zd2-m-dalsi", "font_small", "Another elevator? How many more are there to come?")
dialogStr("Další výtah? Kolik jich ještě bude?")


dialogId("zd2-v-odlis0", "font_big", "I can see some differences here... And somehow I don’t think it’s going to be easier.")
dialogStr("Vidím tu jisté drobné odlišnosti... A něco mi říká, že to teď není jednodušší.")


dialogId("zd2-v-odlis1", "font_big", "The last one had a little bit more advantageous architecture, I think.")
dialogStr("Ten minulý měl, myslím, trochu příznivější architekturu.")


dialogId("zd2-v-vlevo", "font_big", "Can you see that thing in the lower left? It must be some ancient religious symbol.")
dialogStr("Vidíš tu věc vlevo dole? To je jistě nějaký prastarý náboženský symbol.")


dialogId("zd2-m-nevid0", "font_small", "Fortunately, I can’t see much of it.")
dialogStr("Naštěstí na něj moc nevidím.")


dialogId("zd2-m-nevid1", "font_small", "If you are right, I’d rather not know what kind of religion it was.")
dialogStr("Jestli máš pravdu, tak radši nechci vědět koho.")


dialogId("zd2-v-symbol", "font_big", "I am afraid that if we use that strange symbol we could unwillingly initiate some dark ritual.")
dialogStr("Bojím se, že při použítí toho podivného symbolu bezděky spustíme nějaký temný rituál.")


dialogId("zd2-m-douf", "font_small", "I just hope it won’t drop on my head.")
dialogStr("Já jen doufám, že mi při tom nespadne na hlavu.")


dialogId("zd2-m-lebka", "font_small", "Another skull. It’s worse than a morgue.")
dialogStr("Zase nějaká lebka. Je to tu horší než v márnici.")


dialogId("zd2-v-haml", "font_big", "It’s worse than Hamlet.")
dialogStr("Je to tu horší než v Hamletovi.")


dialogId("zd2-x-hus0", "font_lightgrey", "Hush, hush!")
dialogStr("Huš, huš!")


dialogId("zd2-x-hus1", "font_lightgrey", "Don’t come near!")
dialogStr("Nepřibližuj se!")


dialogId("zd2-x-kricet", "font_lightgrey", "I’ll scream if you touch me.")
dialogStr("Jestli na mě sáhneš, budu křičet.")


dialogId("zd2-x-krik0", "font_lightgrey", "Aaaaa!")
dialogStr("ááááaa")


dialogId("zd2-x-krik1", "font_lightgrey", "Help!")
dialogStr("Pomóc.")


dialogId("zd2-x-ritual", "font_lightgrey", "I’ll initiate a dark ritual!")
dialogStr("Spustím temný rituál.")


dialogId("zd2-x-nechteme", "font_lightgrey", "Leave me alone!")
dialogStr("Nechte mě na pokoji!")


dialogId("zd2-x-nechme", "font_lightgrey", "Leave me alone and get lost!")
dialogStr("Necháš mě, dej pokoj!")


dialogId("zd2-x-pokoj", "font_lightgrey", "Cut it out!")
dialogStr("Dej pokoj!")


dialogId("zd2-x-fuj", "font_lightgrey", "Yuck, don’t nibble me!")
dialogStr("Fuj, neočuchávej mě!")


dialogId("zd2-x-necurat", "font_lightgrey", "Don’t think you can pee on me.")
dialogStr("Ne že se ke mě vyčůráš.")


dialogId("zd2-x-neklast", "font_lightgrey", "Just forget about laying your spawn here.")
dialogStr("Jestli tady chceš klást jikry, tak na to zapomeň.")
